Class: Persona::Configuration
- Inherits:
-
Object
- Object
- Persona::Configuration
- Defined in:
- lib/persona/configuration.rb
Instance Attribute Summary collapse
-
#async ⇒ Object
Use Sidekiq for async tracking (requires sidekiq gem).
-
#auto_prune_after_days ⇒ Object
Auto-prune events older than N days on each track! call (nil = off).
-
#inactivity_threshold_days ⇒ Object
Days of inactivity before inactive_since? returns true.
-
#max_events_per_record ⇒ Object
Max events stored per trackable record (nil = unlimited).
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
15 16 17 18 19 20 |
# File 'lib/persona/configuration.rb', line 15 def initialize @max_events_per_record = nil @inactivity_threshold_days = 30 @async = false @auto_prune_after_days = nil end |
Instance Attribute Details
#async ⇒ Object
Use Sidekiq for async tracking (requires sidekiq gem)
10 11 12 |
# File 'lib/persona/configuration.rb', line 10 def async @async end |
#auto_prune_after_days ⇒ Object
Auto-prune events older than N days on each track! call (nil = off)
13 14 15 |
# File 'lib/persona/configuration.rb', line 13 def auto_prune_after_days @auto_prune_after_days end |
#inactivity_threshold_days ⇒ Object
Days of inactivity before inactive_since? returns true
7 8 9 |
# File 'lib/persona/configuration.rb', line 7 def inactivity_threshold_days @inactivity_threshold_days end |
#max_events_per_record ⇒ Object
Max events stored per trackable record (nil = unlimited)
4 5 6 |
# File 'lib/persona/configuration.rb', line 4 def max_events_per_record @max_events_per_record end |